treewide: Clean up string parameters

Change-Id: I0d3ea6a83465181d3edec1587ff824103489072e
Signed-off-by: William A. Kennington III <wak@google.com>
diff --git a/src/network_manager.hpp b/src/network_manager.hpp
index edd7125..18bb7d5 100644
--- a/src/network_manager.hpp
+++ b/src/network_manager.hpp
@@ -53,9 +53,10 @@
     /** @brief Constructor to put object onto bus at a dbus path.
      *  @param[in] bus - Bus to attach to.
      *  @param[in] objPath - Path to attach at.
      *  @param[in] dir - Network Configuration directory path.
      */
-    Manager(sdbusplus::bus_t& bus, const char* objPath, const std::string& dir);
+    Manager(sdbusplus::bus_t& bus, const char* objPath,
+            const fs::path& confDir);
 
     ObjectPath vlan(std::string interfaceName, uint32_t id) override;
@@ -53,9 +53,10 @@
      *  @param[in] bus - Bus to attach to.
      *  @param[in] objPath - Path to attach at.
-     *  @param[in] dir - Network Configuration directory path.
+     *  @param[in] confDir - Network Configuration directory path.
      */